@@ -47,7 +47,9 @@ typedef struct
 	guint		 context_id;
 } WindowData;
 
-GEDIT_PLUGIN_REGISTER_TYPE (GeditCharmapPlugin, gedit_charmap_plugin)
+GEDIT_PLUGIN_REGISTER_TYPE_WITH_CODE (GeditCharmapPlugin, gedit_charmap_plugin,
+		gedit_charmap_panel_register_type (module);
+)
 
 static void
 gedit_charmap_plugin_init (GeditCharmapPlugin *plugin)
@@ -250,7 +252,7 @@ impl_activate (GeditPlugin *plugin,
 	
 	gedit_panel_add_item (panel,
 			      data->panel,
-			      N_("Character Map"),
+			      _("Character Map"),
 			      image);
 
 	gtk_object_sink (GTK_OBJECT (image));
